@@ -15,10 +15,12 @@ class YaCaptcha(forms.widgets.Widget):
     def render(self, name, value, attrs=None):
         client = Cleanweb(key=self.key)
         cap_dict = client.get_captcha()
+
         return render_to_string(DEFAULT_WIDGET_TEMPLATE,
                                 {'yacaptcha_img_url': cap_dict['url'],
-                                 'yacaptcha_response_field': cap_dict['captcha']
+                                 'yacaptcha_response_field': cap_dict['captcha'],
+                                 'attributes': self.attrs
                                 })
 
     def value_from_datadict(self, data, files, name):
-        return [data.get('yacaptcha_challenge_field', None), data.get('yacaptcha_response_field', None)]
\ No newline at end of file
+        return [data.get('yacaptcha_challenge_field', None), data.get('yacaptcha_response_field', None)]
